@@ -1,28 +1,30 @@
 #' @title Estimate a Robust Bayesian Meta-Analysis
 #'
-#' @description \code{RoBMA} is used to estimate a Robust Bayesian
-#' Meta-Analysis. The interface allows a complete customization of
+#' @description \code{RoBMA} is used to estimate a robust Bayesian
+#' meta-analysis. The interface allows a complete customization of
 #' the ensemble with different prior (or list of prior) distributions
 #' for each component.
 #'
 #' @param data a data object created by the \code{combine_data} function. This is
 #' an alternative input entry to specifying the \code{d}, \code{r}, \code{y}, etc...
-#' directly. I.e., you cannot pass the a data.frame and reference to the columns.
+#' directly. I.e., RoBMA function does not allow passing a data.frame and
+#' referencing to the columns.
 #' @param model_type string specifying the RoBMA ensemble. Defaults to \code{NULL}.
 #' The other options are \code{"PSMA"}, \code{"PP"}, and \code{"2w"} which override
 #' settings passed to the \code{priors_effect}, \code{priors_heterogeneity},
 #' \code{priors_effect}, \code{priors_effect_null}, \code{priors_heterogeneity_null},
 #' \code{priors_bias_null}, and \code{priors_effect}. See details for more information
 #' about the different model types.
-#' @param effect_direction the expected direction of the effect. The one-sided
-#' selection sets the weights omega to 1 to significant results in the expected
-#' direction. Defaults to \code{"positive"} (another option is \code{"negative"}).
-#' @param prior_scale a scale used to define priors. Defaults to \code{"cohens_d"}.
+#' @param effect_direction the expected direction of the effect. Correctly specifying
+#' the expected direction of the effect is crucial for one-sided selection models,
+#' as they specify cut-offs using one-sided p-values. Defaults to \code{"positive"}
+#' (another option is \code{"negative"}).
+#' @param prior_scale an effect size scale used to define priors. Defaults to \code{"cohens_d"}.
 #' Other options are \code{"fishers_z"}, correlation coefficient \code{"r"},
 #' and \code{"logOR"}. The prior scale does not need to match the effect sizes measure -
 #' the samples from prior distributions are internally transformed to match the
 #' \code{transformation} of the data. The \code{prior_scale} corresponds to
-#' the scale of default output, but can be changed within the summary function.
+#' the effect size scale of default output, but can be changed within the summary function.
 #' @param priors_effect list of prior distributions for the effect size (\code{mu})
 #' parameter that will be treated as belonging to the alternative hypothesis. Defaults to
 #' a standard normal distribution
@@ -451,6 +453,7 @@ update.RoBMA <- function(object, refit_failed = TRUE, extend_all = FALSE,
       stop("Adding a new model to the ensemble is not possible with RoBMA.reg models.")
 
     what_to_do <- "fit_new_model"
+    message("Fitting a new model with specified priors.")
     new_priors <- .check_and_list_priors(
       model_type = NULL,
       priors_effect_null        = prior_effect_null,        priors_effect        = prior_effect,
@@ -470,6 +473,7 @@ update.RoBMA <- function(object, refit_failed = TRUE, extend_all = FALSE,
   }else if(!is.null(prior_weights)){
 
     what_to_do <- "update_prior_weights"
+    message("Updating prior odds for the fitted models.")
     if(length(prior_weights) != length(object$models))
       stop("The number of newly specified prior odds does not match the number of models. See '?update.RoBMA' for more details.")
     for(i in 1:length(object$models)){
@@ -485,10 +489,19 @@ update.RoBMA <- function(object, refit_failed = TRUE, extend_all = FALSE,
   }else if(extend_all){
 
     what_to_do <- "extend_all"
+    message("Extending all models with additional samples.")
 
   }else if(refit_failed & any(!.get_model_convergence(object))){
 
     what_to_do <- "refit_failed_models"
+    message("Refitting models that failed to converge.")
+
+  }else if(!is.null(convergence_checks)){
+
+    # dispatches separately from the rest of the settings
+    # recomputing convergence can take a bit of time
+    what_to_do <- "update_convergence_checks"
+    message("Updating convergence checks.")
 
   }else{
 
@@ -544,6 +557,13 @@ update.RoBMA <- function(object, refit_failed = TRUE, extend_all = FALSE,
 
     }
 
+  }else if(what_to_do == "update_convergence_checks"){
+
+    # propagate settings changes to the individual models
+    for(i in seq_along(object$models)){
+      object$models[[i]] <- .update_model_checks(object$models[[i]], object[["convergence_checks"]])
+    }
+
   }else if(what_to_do == "transform_estimates"){
 
     # TODO: implement
